lme
===

Cotação London Metal Exchange usando Quandl
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. image:: https://travis-ci.org/mulhergorila/lme.svg?branch=master
    :target: https://travis-ci.org/mulhergorila/lme

.. image:: https://pyup.io/repos/github/mulhergorila/lme/shield.svg
     :target: https://pyup.io/repos/github/mulhergorila/lme/
     :alt: Updates

.. image:: https://pyup.io/repos/github/mulhergorila/lme/python-3-shield.svg
     :target: https://pyup.io/repos/github/mulhergorila/lme/
     :alt: Python 3

`Quandl <https://www.quandl.com/>`__

-  Register an account on Quandl
-  After logging in, click on Me and then Account settings to find the API key

`Quandl in Github <https://github.com/quandl/quandl-python>`__
